﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Common;
using ICSharpCode.TextEditor;
using System.IO;
using System.Diagnostics;

namespace WebBrowserExDemo
{
	public partial class Form1 : Form
	{
		TextEditorControl _Editor = null;
		WebBrowserEx _Browser = null;

		string _BaseDir = String.Empty;

		public Form1()
		{
			InitializeComponent();

			_Editor = new TextEditorControl();
			_Editor.Dock = DockStyle.Fill;
			_Editor.TabIndex = 0;
			splitContainer1.Panel1.Controls.Add( _Editor );

			_Browser = new WebBrowserEx();
			_Browser.Dock = DockStyle.Fill;
			_Browser.TabIndex = 1;
			splitContainer1.Panel2.Controls.Add( _Browser );

			Shown += ( s, e ) => HandleShown();

			_Editor.SetHighlighting( "HTML" );
			_Editor.TextChanged += ( s, e ) => HandleTextChanged();

			_BaseDir = Path.Combine( Application.StartupPath, "..\\.." );
			Debug.WriteLine( "BaseDirectory: " + _BaseDir );
		}

		void HandleShown()
		{
			_Editor.Text =
@"<html>
<head>
<title>WebBrowserEx Demo</title>
<link rel='stylesheet' type='text/css' href='http://www.codeproject.com/App_Themes/NetCommunity/CodeProject.css' />
<style type='text/css'>
BODY { margin: 10px; background-color: #FFF8DF; }
</style>
</head>
<body>
<h1>WebBrowserEx Demo</h1>
<p>
The <code>WebBrowserEx</code> window is
running its own private HTTP server.
</p>
<p>
The HTML is passed as a
<code class='code-keyword'>string</code>, but
it uses: <code>Navigate( url )</code>,
not: <code>DocumentText = html</code>.
This means everything works again:
<ul>
<li>Links to anchors</li>
<li>Links to files</li>
<li>Images stored in files</li>
</ul>
</p>
<p>
All this is wrapped up in the <code>WebBrowserEx</code> control,
which is in one source file less than 200 lines long.
Just pass your HTML to <code>LoadHtml(html,baseDir)</code>.
</p>
<p>
A link to an anchor: &lt;a href='#conclusion'&gt;Conclusion&lt;/a&gt;
<a href='#conclusion'>Conclusion</a>
</p>
<p>
A link to a zip file: &lt;a href='demo.zip'&gt;Demo.zip&lt;/a&gt;
<a href='demo.zip'>Demo.zip</a>
</p>
<p>
An image file: &lt;img src='image.png' /&gt;
<img src='image.png' align='absmiddle' />
</p>
<h2><a name='conclusion'>Conclusion</a></h2>
<p>
Well, that's about it.
I hope you have enjoyed reading this article.
</p>
</body>
</html>
";
		}

		void HandleTextChanged()
		{
			_Browser.LoadHtml( _Editor.Text, _BaseDir );
		}
	}
}
